Crate mint2d
mint2d
0.1.2
All Items
Crate Items
Modules
Structs
Crate
mint2d
Modules

core
Core window, context and state management.
input
Manages keyboard and mouse input and the cursor.
Structs

Point
A simple struct that represents a point or position.
Size
A simple struct that represents the size of an object.